@@ -1,6 +1,7 @@
 import os 
 import sys
 import shutil
+import time 
 
 # utils
 def get (l, idx, default):
@@ -24,12 +25,16 @@ if __name__ == '__main__':
     # read parameter 
     app_name = get(sys.argv, 1, default='app') 
     app_dir = get(sys.argv, 2, default=os.getcwd()) 
+    print("[INFO] prepare to create a new Flask Scaffoling Base with name %s in path %s" % (app_name, app_dir))
+    time.sleep(2)
 
     # check
     app_path = os.path.join(app_dir, app_name)
     app_path_exist = os.path.exists(app_path)
     base_path_valid = os.path.exists(app_dir)
 
+    print("[INFO] checking for full path %s" % app_path)
+    time.sleep(2)
     if not app_path_exist and base_path_valid : 
         os.mkdir(app_path)
         try : 
